@@ -49,7 +49,7 @@ def get_label_file_dict(self, schema_id = None, use_session = True):
         # Add Auth
         response = requests.get(self.host + endpoint,
                                 params = params,
-                                headers = {'directory_id': str(self.directory_id)},
+                                headers = {'schema_id': str(schema_id)},
                                 auth = self.get_http_auth())
 
     self.handle_errors(response)
@@ -57,5 +57,6 @@ def get_label_file_dict(self, schema_id = None, use_session = True):
     data = response.json()
     if data["log"]["success"] == True:
         self.name_to_file_id = data["name_to_file_id"]
+        print("Loaded schema")
     else:
         raise Exception(data["log"]["errors"])
